/**
 * @license e-Calendar v0.9.3
 * (c) 2014-2016 - Jhonis de Souza
 * License: GNU
 */

(function ($) {

    var eCalendar = function (options, object) {
        // Initializing global variables
        var adDay = new Date().getDate();
        var adMonth = new Date().getMonth();
        var adYear = new Date().getFullYear();
        var dDay = adDay;
        var dMonth = adMonth;
        var dYear = adYear;
        var instance = object;

        var settings = $.extend({}, $.fn.eCalendar.defaults, options);

        function lpad(value, length, pad) {
            if (typeof pad == 'undefined') {
                pad = '0';
            }
            var p;
            for (var i = 0; i < length; i++) {
                p += pad;
            }
            return (p + value).slice(-length);
        }

        var mouseOver = function () {
            $(this).addClass('c-nav-btn-over');
        };
        var mouseLeave = function () {
            $(this).removeClass('c-nav-btn-over');
        };
        var mouseOverEvent = function () {
            $(this).addClass('c-event-over');
            var d = $(this).attr('data-event-day');
            $('div.c-event-item[data-event-day="' + d + '"]').addClass('c-event-over');
        };
        var mouseLeaveEvent = function () {
            $(this).removeClass('c-event-over')
            var d = $(this).attr('data-event-day');
            $('div.c-event-item[data-event-day="' + d + '"]').removeClass('c-event-over');
        };
        var mouseOverItem = function () {
            $(this).addClass('c-event-over');
            var d = $(this).attr('data-event-day');
            $('div.c-event[data-event-day="' + d + '"]').addClass('c-event-over');
        };
        var mouseLeaveItem = function () {
            $(this).removeClass('c-event-over')
            var d = $(this).attr('data-event-day');
            $('div.c-event[data-event-day="' + d + '"]').removeClass('c-event-over');
        };
        var nextMonth = function () {
            if (dMonth < 11) {
                dMonth++;
            } else {
                dMonth = 0;
                dYear++;
            }
            print();
        };
        var previousMonth = function () {
            if (dMonth > 0) {
                dMonth--;
            } else {
                dMonth = 11;
                dYear--;
            }
            print();
        };

        function loadEvents() {
            if (typeof settings.url != 'undefined' && settings.url != '') {
                $.ajax({url: settings.url,
                    async: false,
                    success: function (result) {
                        settings.events = result;
                    }
                });
            }
        }

        function print() {
            loadEvents();
            var dWeekDayOfMonthStart = new Date(dYear, dMonth, 1).getDay() - settings.firstDayOfWeek;
            if (dWeekDayOfMonthStart < 0) {
                dWeekDayOfMonthStart = 6 - ((dWeekDayOfMonthStart + 1) * -1);
            }
            var dLastDayOfMonth = new Date(dYear, dMonth + 1, 0).getDate();
            var dLastDayOfPreviousMonth = new Date(dYear, dMonth + 1, 0).getDate() - dWeekDayOfMonthStart + 1;

            var cBody = $('<div/>').addClass('c-grid');
            var cEvents = $('<div/>').addClass('c-event-grid');
            var cEventsBody = $('<div/>').addClass('c-event-body');
            cEvents.append($('<div/>').addClass('c-event-title c-pad-top').html(settings.eventTitle));
            cEvents.append(cEventsBody);
            var cNext = $('<div/>').addClass('c-next c-grid-title c-pad-top');
            var cMonth = $('<div/>').addClass('c-month c-grid-title c-pad-top');
            var cPrevious = $('<div/>').addClass('c-previous c-grid-title c-pad-top');
            cPrevious.html(settings.textArrows.previous);
            cMonth.html(settings.months[dMonth] + ' ' + dYear);
            cNext.html(settings.textArrows.next);

            cPrevious.on('mouseover', mouseOver).on('mouseleave', mouseLeave).on('click', previousMonth);
            cNext.on('mouseover', mouseOver).on('mouseleave', mouseLeave).on('click', nextMonth);

            cBody.append(cPrevious);
            cBody.append(cMonth);
            cBody.append(cNext);
            var dayOfWeek = settings.firstDayOfWeek;
            for (var i = 0; i < 7; i++) {
                if (dayOfWeek > 6) {
                    dayOfWeek = 0;
                }
                var cWeekDay = $('<div/>').addClass('c-week-day c-pad-top');
                cWeekDay.html(settings.weekDays[dayOfWeek]);
                cBody.append(cWeekDay);
                dayOfWeek++;
            }
            var day = 1;
            var dayOfNextMonth = 1;
            for (var i = 0; i < 42; i++) {
                var cDay = $('<div/>');
                if (i < dWeekDayOfMonthStart) {
                    cDay.addClass('c-day-previous-month c-pad-top');
                    cDay.html(dLastDayOfPreviousMonth++);
                } else if (day <= dLastDayOfMonth) {
                    cDay.addClass('c-day c-pad-top');
                    if (day == dDay && adMonth == dMonth && adYear == dYear) {
                        cDay.addClass('c-today');
                    }
                    for (var j = 0; j < settings.events.length; j++) {
                        var d = settings.events[j].datetime;
                        if (d.getDate() == day && d.getMonth() == dMonth && d.getFullYear() == dYear) {
                            cDay.addClass('c-event').attr('data-event-day', d.getDate());
                            cDay.on('mouseover', mouseOverEvent).on('mouseleave', mouseLeaveEvent);
                        }
                    }
                    cDay.html(day++);
                } else {
                    cDay.addClass('c-day-next-month c-pad-top');
                    cDay.html(dayOfNextMonth++);
                }
                cBody.append(cDay);
            }
            var eventList = $('<div/>').addClass('c-event-list');
            for (var i = 0; i < settings.events.length; i++) {
                var d = settings.events[i].datetime;
                if (d.getMonth() == dMonth && d.getFullYear() == dYear) {
                    var date = lpad(d.getDate(), 2) + '/' + lpad(d.getMonth() + 1, 2) + ' ' ;
                    //+ lpad(d.getHours(), 2) + ':' + lpad(d.getMinutes(), 2) 
                    //cambio esto estaba al final de la anterior
                    var item = $('<div/>').addClass('c-event-item');
                    var title = $('<div/>').addClass('title').html(date + '  ' + settings.events[i].title + '<br/>');
                    var description = $('<div/>').addClass('description').html(settings.events[i].description + '<br/>');
                    item.attr('data-event-day', d.getDate());
                    item.on('mouseover', mouseOverItem).on('mouseleave', mouseLeaveItem);
                    item.append(title).append(description);

                    // Add the url to the description if is set
                    if( settings.events[i].url !== undefined )
                    {
                        /**
                         * If the setting url_blank is set and is true, the target of the url
                         * will be "_blank"
                         */
                        type_url = settings.events[i].url_blank !== undefined && 
                                   settings.events[i].url_blank === true ? 
                                   '_blank':'';
                        description.wrap( '<a href="'+ settings.events[i].url +'" target="'+type_url+'" ></a>' );
                    }

                    eventList.append(item);
                }
            }
            $(instance).addClass('calendar');
            cEventsBody.append(eventList);
            $(instance).html(cBody).append(cEvents);
        }

        return print();
    }

    $.fn.eCalendar = function (oInit) {
        return this.each(function () {
            return eCalendar(oInit, $(this));
        });
    };

    // plugin defaults
    $.fn.eCalendar.defaults = {
        weekDays: ['Dom', 'Lun', 'Mar', 'Mie', 'Jue', 'Vie', 'Sab'],
        months: ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'],
        textArrows: {previous: '<', next: '>'},
        eventTitle: 'Calendario fiscal',
        url: '',
        events: [
            {title: 'Evento de Abertura', description: 'Abertura das Olimpíadas Rio 2016', datetime: new Date(2016, new Date().getMonth(), 12, 17)},
   
    
    {title: 'Retenciones cuarto trimestre del año anterior', description: 'Modelo 115: rendimientos procedentes del arrendamiento <br /> o subarrendamientos de inmuebles urbanos.<br />Modelo 111: retenciones e ingresos a cuenta del IRPF de los<br />trabajadores de la empresa .', datetime: new Date(new Date().getFullYear(), 0, 20, 0)},
   {title: 'IRPF', description: 'Modelos 130 y 131. Pagos fraccionados del 4ª trimestre<br />del año anterior.', datetime: new Date(new Date().getFullYear(), 0, 30, 0)},
   {title: 'IVA', description: 'Modelo 303: Primer trimestre. Autoliquidación. <br />Modelo 390: resumen anual del año anterior. <br />Modelo 349: 4º trimestre año anterior, declaración recapitulativa <br />de operaciones intracomunitarias. ', datetime: new Date(new Date().getFullYear(), 0, 30, 0)},
   {title: 'Retenciones anuales del año anterior', description: 'Modelos 180 y 190: resumen anual del año anterior.', datetime: new Date(new Date().getFullYear(), 0, 31, 0)},

     {title: 'Operaciones con terceros', description: 'Modelo 347: declaración anual de operaciones con terceros<br /> (año anterior). ', datetime: new Date(new Date().getFullYear(), 1, 28, 0)},

   {title: 'Impuesto sobre Sociedades', description: 'Modelo 202: pagos fraccionados ejercicio en curso.', datetime: new Date(new Date().getFullYear(), 3, 20, 0)},
 {title: 'Retenciones primer trimestre del año actual', description: 'Modelo 115: rendimientos procedentes del arrendamiento <br /> o subarrendamientos de inmuebles urbanos.<br />Modelo 111: retenciones e ingresos a cuenta del IRPF de los<br />trabajadores de la empresa .', datetime: new Date(new Date().getFullYear(), 3, 20, 0)},
  {title: 'IVA', description: 'Modelo 303: cuarto trimestre del año anterior. Autoliquidación. <br />Modelo 349: primer trimestre, declaración recapitulativa de<br />operaciones intracomunitarias. ', datetime: new Date(new Date().getFullYear(), 3, 20, 0)},
  {title: 'IRPF', description: 'Modelos 130, 131 y 202. Pagos fraccionados, 1er trimestre.', datetime: new Date(new Date().getFullYear(), 3, 20, 0)},
  

 {title: 'IRPF', description: 'Modelos D-100 y D-714: borrador y declaración anual del <br />pasado año.<br /> Puedes presentarlo hasta finales de junio.', datetime: new Date(new Date().getFullYear(), 4, 11, 0)},

 {title: 'IRPF', description: 'Modelos D-100 y D-714: borrador y declaración anual del <br />pasado año con resultado a ingresar.', datetime: new Date(new Date().getFullYear(), 5, 25, 0)},
 {title: 'IRPF', description: 'Modelos D-100 y D-714: borrador y declaración anual del <br />pasado año con resultado a devolver.', datetime: new Date(new Date().getFullYear(), 5, 30, 0)},

 {title: 'Retenciones segundo trimestre del año actual', description: 'Modelo 115: rendimientos procedentes del arrendamiento <br /> o subarrendamientos de inmuebles urbanos.<br />Modelo 111: retenciones e ingresos a cuenta del IRPF de los<br />trabajadores de la empresa .', datetime: new Date(new Date().getFullYear(), 6, 20, 0)},
  {title: 'IRPF', description: 'Modelos 130, 131 y 202. Pagos fraccionados, 2º trimestre.', datetime: new Date(new Date().getFullYear(), 6, 20, 0)},
{title: 'IVA', description: 'Modelo 303: segundo trimestre. Autoliquidación. <br />Modelo 349: 2º trimestre del año, declaración recapitulativa <br />de operaciones intracomunitarias. ', datetime: new Date(new Date().getFullYear(), 6, 20, 0)},
{title: 'Impuesto sobre Sociedades', description: 'Modelo 200: declaración anual del pasado año. ', datetime: new Date(new Date().getFullYear(), 6, 25, 0)},


{title: 'Retenciones del tercer trimestre del año actual', description: 'Modelo 115: rendimientos procedentes del arrendamiento <br /> o subarrendamientos de inmuebles urbanos.<br />Modelo 111: retenciones e ingresos a cuenta del IRPF de los<br />trabajadores de la empresa .', datetime: new Date(new Date().getFullYear(), 9, 20, 0)},
  {title: 'IRPF', description: 'Modelos 130, 131 y 202. Pagos fraccionados, 3er trimestre.', datetime: new Date(new Date().getFullYear(), 9, 20, 0)},
 {title: 'Impuesto sobre Sociedades', description: 'Modelo 202: pagos fraccionados ejercicio en curso.', datetime: new Date(new Date().getFullYear(), 9, 20, 0)},
{title: 'IVA', description: 'Modelo 303: tercer trimestre. Autoliquidación. <br />Modelo 349: 3er trimestre del año, declaración recapitulativa <br />de operaciones intracomunitarias. ', datetime: new Date(new Date().getFullYear(), 9, 20, 0)},

 {title: 'Impuesto sobre Sociedades', description: 'Modelo 202: pagos fraccionados ejercicio en curso.', datetime: new Date(new Date().getFullYear(), 11, 20, 0)},

 {title: 'IRPF', description: ' Modelos 036 y 037. Renuncia o revocación estimación directa simplificada y estimación objetiva (módulos) para este año y sucesivos.', datetime: new Date(new Date().getFullYear()+1, 0, 2, 0)},
 {title: 'IVA', description: ' Modelos 036 y 037. Renuncia o revocación regímenes simplificado y agricultura, ganadería y pesca para este año y sucesivos.', datetime: new Date(new Date().getFullYear()+1, 0, 2, 0)}


 

        ],
        firstDayOfWeek: 0
    };

}(jQuery));